==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/vi.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'vi', {
	acccessKey: 'Phím hỗ trợ truy cập',
	advanced: 'Mở rộng',
	advisoryContentType: 'Nội dung hướng dẫn',
	advisoryTitle: 'Nhan đề hướng dẫn',
	anchor: {
		toolbar: 'Chèn/Sửa điểm neo',
		menu: 'Thuộc tính điểm neo',
		title: 'Thuộc tính điểm neo',
		name: 'Tên của điểm neo',
		errorName: 'Hãy nhập vào tên của điểm neo',
		remove: 'Xóa neo'
	},
	anchorId: 'Theo định danh thành phần',
	anchorName: 'Theo tên điểm neo',
	charset: 'Bảng mã của tài nguyên được liên kết đến',
	cssClasses: 'Lớp Stylesheet',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Thư điện tử',
	emailBody: 'Nội dung thông điệp',
	emailSubject: 'Tiêu đề thông điệp',
	id: 'Định danh',
	info: 'Thông tin liên kết',
	langCode: 'Mã ngôn ngữ',
	langDir: 'Hướng ngôn ngữ',
	langDirLTR: 'Trái sang phải (LTR)',
	langDirRTL: 'Phải sang trái (RTL)',
	menu: 'Sửa liên kết',
	name: 'Tên',
	noAnchors: '(Không có điểm neo nào trong tài liệu)',
	noEmail: 'Hãy đưa vào địa chỉ thư điện tử',
	noUrl: 'Hãy đưa vào đường dẫn liên kết (URL)',
	other: '<khác>',
	popupDependent: 'Phụ thuộc (Netscape)',
	popupFeatures: 'Đặc điểm của cửa sổ Popup',
	popupFullScreen: 'Toàn màn hình (IE)',
	popupLeft: 'Vị trí bên trái',
	popupLocationBar: 'Thanh vị trí',
	popupMenuBar: 'Thanh Menu',
	popupResizable: 'Có thể thay đổi kích cỡ',
	popupScrollBars: 'Thanh cuộn',
	popupStatusBar: 'Thanh trạng thái',
	popupToolbar: 'Thanh công cụ',
	popupTop: 'Vị trí phía trên',
	rel: 'Quan hệ',
	selectAnchor: 'Chọn một điểm neo',
	styles: 'Kiểu (style)',
	tabIndex: 'Chỉ số của Tab',
	target: 'Đích',
	targetFrame: '<khung>',
	targetFrameName: 'Tên khung đích',
	targetPopup: '<cửa sổ popup>',
	targetPopupName: 'Tên cửa sổ Popup',
	title: 'Liên kết',
	toAnchor: 'Neo trong trang này',
	toEmail: 'Thư điện tử',
	toUrl: 'URL',
	toolbar: 'Chèn/Sửa liên kết',
	type: 'Kiểu liên kết',
	unlink: 'Xoá liên kết',
	upload: 'Tải lên'
} );

==> ldap-account-manager_8.0.1.orig.tar.bz2: ldap-account-manager-8.0.1/templates/lib/extra/ckeditor/plugins/link/lang/vi.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'vi', {
	acccessKey: 'Phím hỗ trợ truy cập',
	advanced: 'Mở rộng',
	advisoryContentType: 'Nội dung hướng dẫn',
	advisoryTitle: 'Nhan đề hướng dẫn',
	anchor: {
		toolbar: 'Chèn/Sửa điểm neo',
		menu: 'Thuộc tính điểm neo',
		title: 'Thuộc tính điểm neo',
		name: 'Tên của điểm neo',
		errorName: 'Hãy nhập vào tên của điểm neo',
		remove: 'Xóa neo'
	},
	anchorId: 'Theo định danh thành phần',
	anchorName: 'Theo tên điểm neo',
	charset: 'Bảng mã của tài nguyên được liên kết đến',
	cssClasses: 'Lớp Stylesheet',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Thư điện tử',
	emailBody: 'Nội dung thông điệp',
	emailSubject: 'Tiêu đề thông điệp',
	id: 'Định danh',
	info: 'Thông tin liên kết',
	langCode: 'Mã ngôn ngữ',
	langDir: 'Hướng ngôn ngữ',
	langDirLTR: 'Trái sang phải (LTR)',
	langDirRTL: 'Phải sang trái (RTL)',
	menu: 'Sửa liên kết',
	name: 'Tên',
	noAnchors: '(Không có điểm neo nào trong tài liệu)',
	noEmail: 'Hãy đưa vào địa chỉ thư điện tử',
	noUrl: 'Hãy đưa vào đường dẫn liên kết (URL)',
	noTel: 'Please type the phone number', // MISSING
	other: '<khác>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Phụ thuộc (Netscape)',
	popupFeatures: 'Đặc điểm của cửa sổ Popup',
	popupFullScreen: 'Toàn màn hình (IE)',
	popupLeft: 'Vị trí bên trái',
	popupLocationBar: 'Thanh vị trí',
	popupMenuBar: 'Thanh Menu',
	popupResizable: 'Có thể thay đổi kích cỡ',
	popupScrollBars: 'Thanh cuộn',
	popupStatusBar: 'Thanh trạng thái',
	popupToolbar: 'Thanh công cụ',
	popupTop: 'Vị trí phía trên',
	rel: 'Quan hệ',
	selectAnchor: 'Chọn một điểm neo',
	styles: 'Kiểu (style)',
	tabIndex: 'Chỉ số của Tab',
	target: 'Đích',
	targetFrame: '<khung>',
	targetFrameName: 'Tên khung đích',
	targetPopup: '<cửa sổ popup>',
	targetPopupName: 'Tên cửa sổ Popup',
	title: 'Liên kết',
	toAnchor: 'Neo trong trang này',
	toEmail: 'Thư điện tử',
	toUrl: 'URL',
	toPhone: 'Phone', // MISSING
	toolbar: 'Chèn/Sửa liên kết',
	type: 'Kiểu liên kết',
	unlink: 'Xoá liên kết',
	upload: 'Tải lên'
} );
